from getpass import getpass
from classes.Signature import Signature

class User:
    def __init__(self, db, private_key=None, public_key=None, username=None, password=None):
        self.db = db
        self.private_key = private_key
        self.public_key = public_key
        self.username = username
        self.password = password

    def login(self):
        input_username = input("Username: ")
        input_password = getpass("Password: ")

        user = self.db.loginUser(input_username, input_password)

        # check if user exists
        if user:
            private_key, public_key = Signature.bytes_to_keys(user['private_key'], user['public_key'])
            self.private_key = private_key
            self.public_key = public_key
            self.username = user['username']
            return True    
        return False

    def register(self):
        input_username = input("Username: ")
        input_password = getpass("Password: ")

        # check if username is already taken
        if self.db.fetchUserByUsername(input_username):
            return False

        # create sig for user
        private_key, public_key = Signature.generate_keys()
        private_ser, public_ser = Signature.keys_to_bytes(private_key, public_key)
        # register user
        if self.db.createUser( private_ser, public_ser, input_username, input_password):
            self.private_key = private_key
            self.public_key = public_key
            self.username = input_username
            return True
        return False
    
    def logout(self):
        self.db.close()
        self.private_key = None
        self.public_key = None
        self.username = None
        self.password = None
        return True